from .main import tokenize
from .main import rel_freq
from .main import tf_idf